from mayan.apps.dependencies.classes import PythonDependency

PythonDependency(
    module=__name__, name='gevent', version_string='==24.2.1'
)
PythonDependency(
    module=__name__, name='greenlet', version_string='==3.0.3'
)
PythonDependency(
    module=__name__, name='gunicorn', version_string='==22.0.0'
)
PythonDependency(
    module=__name__, name='sentry-sdk', version_string='==2.35.0'
)
PythonDependency(
    module=__name__, name='whitenoise', version_string='==6.7.0'
)
